@@ -234,7 +234,15 @@ QVariant FlatpakPermissionModel::data(const QModelIndex &index, int role) const
     case Roles::IsNotDummy:
         return permission.pType() != FlatpakPermission::Dummy;
     case Roles::SectionType:
-        return permission.sType() == FlatpakPermission::Basic ? permission.type() == FlatpakPermission::Filesystems ? i18n("Filesystem Access") : i18n("Basic Permissions") : i18n("Advanced Permissions");
+        if (permission.sType() == FlatpakPermission::Basic) {
+            if (permission.type() == FlatpakPermission::Filesystems) {
+                return i18n("Filesystem Access");
+            } else {
+                return i18n("Basic Permissions");
+            }
+        } else {
+            return i18n("Advanced Permissions");
+        }
     case Roles::IsBasic:
         return permission.sType() == FlatpakPermission::Basic;
     case Roles::ValueList:
@@ -581,6 +589,7 @@ void FlatpakPermissionModel::loadDefaultValues()
     }
     /* SYSTEM BUS category */
 
+#if 0 // Disabled because BUG 465502
     /* ENVIRONMENT category */
     category = i18n("Environment");
     const KConfigGroup environmentGroup = parser.group("Environment");
@@ -600,6 +609,7 @@ void FlatpakPermissionModel::loadDefaultValues()
         m_permissions.append(perm);
     }
     /* ENVIRONMENT category */
+#endif
 }
 
 void FlatpakPermissionModel::loadCurrentValues()
@@ -805,16 +815,17 @@ bool FlatpakPermissionModel::isSaveNeeded() const
     });
 }
 
-void FlatpakPermissionModel::setReference(FlatpakReference *ref)
+void FlatpakPermissionModel::setReference(FlatpakReference *reference)
 {
-    if (!ref) {
-        return;
-    }
-
-    if(m_reference != ref) {
+    if (reference != m_reference) {
         beginResetModel();
-        m_reference = ref;
-        m_reference->setPermsModel(this);
+        if (m_reference) {
+            m_reference->setPermsModel(nullptr);
+        }
+        m_reference = reference;
+        if (m_reference) {
+            m_reference->setPermsModel(this);
+        }
         endResetModel();
         Q_EMIT referenceChanged();
     }
@@ -922,7 +933,7 @@ void FlatpakPermissionModel::setPerm(int index)
 void FlatpakPermissionModel::editPerm(int index, QString newValue)
 {
     /* guard for out-of-range indices */
-    if (index < 0 || index > m_permissions.length()) {
+    if (index < 0 || index >= m_permissions.length()) {
         return;
     }
 
