@@ -9,6 +9,7 @@
 
 #include <QString>
 #include <QAbstractListModel>
+#include <QPointer>
 
 class FlatpakReference;
 
@@ -109,8 +110,8 @@ public:
     };
 
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
-    QVariant data(const QModelIndex &parent, int role) const override;
-    virtual QHash<int, QByteArray> roleNames() const override;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
+    QHash<int, QByteArray> roleNames() const override;
 
     void loadDefaultValues();
     void loadCurrentValues();
@@ -147,7 +148,8 @@ private:
     int permIndex(QString category, int from = 0);
     void readFromFile();
     void writeToFile();
+
     QVector<FlatpakPermission> m_permissions;
-    FlatpakReference *m_reference;
+    QPointer<FlatpakReference> m_reference;
     QString m_overridesData;
 };
