@@ -14,7 +14,7 @@ extern "C" {
 }
 #endif
 #include <glib.h>
-
+#include <QDebug>
 FlatpakReference::~FlatpakReference() = default;
 
 FlatpakReference::FlatpakReference(FlatpakReferencesModel *parent, QString name, QString id, const QString &path, QString version, QString icon, QByteArray metadata, FlatpakReferencesModel *refsModel)
@@ -25,6 +25,7 @@ FlatpakReference::FlatpakReference(FlatpakReferencesModel *parent, QString name,
       m_icon(icon),
       m_path(path),
       m_metadata(metadata),
+      m_permsModel(nullptr),
       m_refsModel(refsModel)
 {
     m_path.append(m_id);
@@ -68,42 +69,67 @@ FlatpakPermissionModel *FlatpakReference::permsModel()
 
 void FlatpakReference::setPermsModel(FlatpakPermissionModel *permsModel)
 {
-    m_permsModel = permsModel;
-    connect(m_permsModel, &FlatpakPermissionModel::referenceChanged, this, &FlatpakReference::needsLoad);
-    connect(this, &FlatpakReference::needsLoad, m_refsModel, &FlatpakReferencesModel::needsLoad);
-    connect(m_permsModel, &FlatpakPermissionModel::dataChanged, this, &FlatpakReference::needsSaveChanged);
-    connect(this, &FlatpakReference::needsSaveChanged, m_refsModel, &FlatpakReferencesModel::needsSaveChanged);
+    if (permsModel != m_permsModel) {
+        if (m_permsModel) {
+            disconnect(m_permsModel, &FlatpakPermissionModel::referenceChanged, this, &FlatpakReference::needsLoad);
+            disconnect(this, &FlatpakReference::needsLoad, m_refsModel, &FlatpakReferencesModel::needsLoad);
+            disconnect(m_permsModel, &FlatpakPermissionModel::dataChanged, this, &FlatpakReference::needsSaveChanged);
+            disconnect(this, &FlatpakReference::needsSaveChanged, m_refsModel, &FlatpakReferencesModel::needsSaveChanged);
+        }
+        m_permsModel = permsModel;
+        if (m_permsModel) {
+            connect(m_permsModel, &FlatpakPermissionModel::referenceChanged, this, &FlatpakReference::needsLoad);
+            connect(this, &FlatpakReference::needsLoad, m_refsModel, &FlatpakReferencesModel::needsLoad);
+            connect(m_permsModel, &FlatpakPermissionModel::dataChanged, this, &FlatpakReference::needsSaveChanged);
+            connect(this, &FlatpakReference::needsSaveChanged, m_refsModel, &FlatpakReferencesModel::needsSaveChanged);
+        }
+    }
 }
 
 void FlatpakReference::load()
 {
-    m_permsModel->load();
+    if (m_permsModel) {
+        m_permsModel->load();
+    }
 }
 
 void FlatpakReference::save()
 {
-    m_permsModel->save();
+    if (m_permsModel) {
+        m_permsModel->save();
+    }
 }
 
 void FlatpakReference::defaults()
 {
-    m_permsModel->defaults();
+    if (m_permsModel) {
+        m_permsModel->defaults();
+    }
 }
 
 bool FlatpakReference::isSaveNeeded() const
 {
-    return m_permsModel->isSaveNeeded();
+    if (m_permsModel) {
+        return m_permsModel->isSaveNeeded();
+    }
+    return false;
 }
 
 bool FlatpakReference::isDefaults() const
 {
-    return m_permsModel->isDefaults();
+    if (m_permsModel) {
+        return m_permsModel->isDefaults();
+    }
+    return true;
 }
 
 FlatpakReferencesModel::FlatpakReferencesModel(QObject *parent) : QAbstractListModel(parent)
 {
     g_autoptr(FlatpakInstallation) installation = flatpak_installation_new_system(NULL, NULL);
     g_autoptr(GPtrArray) installedApps = flatpak_installation_list_installed_refs_by_kind(installation, FLATPAK_REF_KIND_APP, NULL, NULL);
+    g_autoptr(FlatpakInstallation) userInstallation = flatpak_installation_new_user(NULL, NULL);
+    g_autoptr(GPtrArray) installedUserApps = flatpak_installation_list_installed_refs_by_kind(userInstallation, FLATPAK_REF_KIND_APP, NULL, NULL);
+    g_ptr_array_extend_and_steal(installedApps, installedUserApps);
     QString path = FlatpakHelper::permDataFilePath();
 
     for(uint i = 0; i < installedApps->len; ++i) {
@@ -113,8 +139,8 @@ FlatpakReferencesModel::FlatpakReferencesModel(QObject *parent) : QAbstractListM
         if (id.endsWith(QStringLiteral(".BaseApp"))) {
             continue;
         }
-        QString icon = FlatpakHelper::iconPath(name, id);
-
+        QString appBasePath = QString::fromUtf8(flatpak_installed_ref_get_deploy_dir(FLATPAK_INSTALLED_REF(g_ptr_array_index(installedApps, i))));
+        QString icon = FlatpakHelper::iconPath(name, id, appBasePath);
         g_autoptr(GBytes) data = flatpak_installed_ref_load_metadata(FLATPAK_INSTALLED_REF(g_ptr_array_index(installedApps, i)), NULL, NULL);
         gsize len = 0;
         auto buff = g_bytes_get_data(data, &len);
